# -*- coding: utf-8 -*-
# Generated by Django 1.11.15 on 2018-12-13 15:23
# This is necessary because django-simple-history 2.6.0 changes the model


import django.db.models.deletion
from django.db import migrations, models

import enterprise.models


class Migration(migrations.Migration):

    dependencies = [
        ('enterprise', '0059_add_code_management_portal_config'),
    ]

    operations = [
        migrations.AlterField(
            model_name='historicalenterprisecourseenrollment',
            name='enterprise_customer_user',
            field=models.ForeignKey(blank=True, db_constraint=False, help_text='The enterprise learner to which this enrollment is attached.', null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='enterprise.EnterpriseCustomerUser'),
        ),
        migrations.AlterField(
            model_name='historicalenterprisecustomer',
            name='customer_type',
            field=models.ForeignKey(blank=True, db_constraint=False, default=enterprise.models.get_default_customer_type, help_text='Specifies enterprise customer type.', null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='enterprise.EnterpriseCustomerType', verbose_name='Customer Type'),
        ),
    ]
